Subject: Perl syntax highlighting regression in fix for #27613? (feecb66b6fe41c977b8e11b5f2d419c9544f42de)

From: Clément Pit-Claudel <[email-masked]>
Date: Tue, 13 Mar 2018 19:14:56 -0400

X-Debbugs-CC: [email-masked]

Hi all,

I think the following commit was a bit too enthusiastic, as variables like @temp are now highlighted in font-lock-type-face.

diff --git a/lisp/progmodes/perl-mode.el b/lisp/progmodes/perl-mode.el
--- a/lisp/progmodes/perl-mode.el
+++ b/lisp/progmodes/perl-mode.el
@@ -181,4 +181,5 @@
      ;;
-     ;; Fontify local and my keywords as types.
-     ("\\<\\(local\\|my\\)\\>" . font-lock-type-face)
+     ;; Fontify declarators and prefixes as types.
+     ("\\<\\(anon\\|argument\\|has\\|local\\|my\\|our\\|state\\|supersede\\)\\>" . font-lock-type-face) ; declarators
+     ("\\<\\(let\\|temp\\)\\>" . font-lock-type-face) ; prefixes
      ;;

Am I missing something? (I don't speak Perl, so I noticed this in a regression test)

Clément.